@@ -54,7 +54,7 @@ use fields qw(
         default_expires removal_strategy size_limit
         load_callback validate_callback);
 
-our $VERSION = '2.03';
+our $VERSION = '2.05';
 
 our $EXPIRES_NOW = 'now';
 our $EXPIRES_NEVER = 'never';
@@ -479,11 +479,19 @@ These methods are only for use internally (by concrete Cache implementations).
 Converts a timespec as described for Cache::Entry::set_expiry() into a unix
 time.
 
+=back
+
 =cut
 
 sub Canonicalize_Expiration_Time {
-    my $timespec = lc($_[0])
-        or return undef;
+    my $timespec;
+
+    my $timespec_param = shift(@_);
+    if (! $timespec_param)
+    {
+        return undef;
+    }
+    $timespec = lc($timespec_param);
 
     my $time;
 
@@ -619,12 +627,12 @@ users.
 
 =head1 COPYRIGHT
 
- Copyright (C) 2003 Chris Leishman.  All Rights Reserved.
+ Copyright (C) 2003-2006 Chris Leishman.  All Rights Reserved.
 
 This module is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
 either expressed or implied. This program is free software; you can
 redistribute or modify it under the same terms as Perl itself.
 
-$Id: Cache.pm,v 1.6 2005/10/20 12:52:03 caleishm Exp $
+$Id: Cache.pm,v 1.7 2006/01/31 15:23:58 caleishm Exp $
 
 =cut
